Removed

Enum Removed 

pub enum Removed<Key, Value> {
    PreviousValue(Value),
    Evicted(Key, Value),
}
A removed value or entry.

Variants



PreviousValue(Value)

The previously stored value for the key that was written to.



Evicted(Key, Value)

An entry was evicted to make room for the key that was written to.